@@ -41,9 +41,13 @@ class StringValueObject(ValueObject):
             raise raise_cls()
 
     def _ensure_value_contains_valid_char(
-        self, raise_cls=InvalidStringValueObjectError
+        self, raise_cls=InvalidStringValueObjectError, allow_utf8mb4: bool = True
     ):
-        if not isinstance(self.value, str) or not re.search(r"^[\w]*(([',. -][\s]?[\w]?)?[\w]*)*$", self.value):
+        if not isinstance(self.value, str) or not re.search(
+            r"^[\w]*(([',. -][\s]?[\w]?)?[\w]*)*$", self.value
+        ):
+            self._raise_error(raise_cls)
+        if not allow_utf8mb4 and re.match("[^\u0000-\uffff]", self.value):
             self._raise_error(raise_cls)
 
     def _ensure_value_is_less_than_n_char(
